@@ -19,9 +19,6 @@ def get_line_bounds(cursor):
     
     return start, end    
     
-def select_range(buffer, start, end):
-    buffer.select_range(end, start)
-    
 def cursor_on_start_or_end_whitespace(cursor):
     if cursor.starts_line() or cursor.ends_line():
         return True
